Simple usage
============

The most straightforward way to use mols2grid! For a more advanced usage, see :class:`~mols2grid.MolGrid`.

.. autofunction:: mols2grid.display

.. autofunction:: mols2grid.save

.. autofunction:: mols2grid.get_selection
